@@ -13,6 +13,9 @@ try:
 except ImportError:
     import simplejson as json
 
+class _DEFAULT(object):
+    pass
+
 class TwitterError(Exception):
     """
     Base Exception thrown by the Twitter object when there is a
@@ -30,13 +33,14 @@ class TwitterHTTPError(TwitterError):
         self.uri = uri
         self.format = format
         self.uriparts = uriparts
+        self.response_data = self.e.fp.read()
 
     def __str__(self):
         return (
             "Twitter sent status %i for URL: %s.%s using parameters: "
             "(%s)\ndetails: %s" %(
                 self.e.code, self.uri, self.format, self.uriparts,
-                self.e.fp.read()))
+                self.response_data))
 
 class TwitterResponse(object):
     """
@@ -75,11 +79,6 @@ def wrap_response(response, headers):
     class WrappedTwitterResponse(response_typ, TwitterResponse):
         __doc__ = TwitterResponse.__doc__
 
-        def __init__(self, response):
-            if response_typ is not int:
-                response_typ.__init__(self, response)
-            TwitterResponse.__init__(self, headers)
-
     return WrappedTwitterResponse(response)
 
 
@@ -101,10 +100,16 @@ class TwitterCall(object):
         try:
             return object.__getattr__(self, k)
         except AttributeError:
-            return self.callable_cls(
-                auth=self.auth, format=self.format, domain=self.domain,
-                callable_cls=self.callable_cls, uriparts=self.uriparts + (k,),
-                secure=self.secure)
+            def extend_call(arg):
+                return self.callable_cls(
+                    auth=self.auth, format=self.format, domain=self.domain,
+                    callable_cls=self.callable_cls, uriparts=self.uriparts \
+                        + (arg,),
+                    secure=self.secure)
+            if k == "_":
+                return extend_call
+            else:
+                return extend_call(k)
 
     def __call__(self, **kwargs):
         # Build the uri.
@@ -240,7 +245,7 @@ class Twitter(TwitterCall):
     def __init__(
         self, format="json",
         domain="api.twitter.com", secure=True, auth=None,
-        api_version='1'):
+        api_version=_DEFAULT):
         """
         Create a new twitter API connector.
 
@@ -260,7 +265,7 @@ class Twitter(TwitterCall):
         HTTPS.
 
         `api_version` is used to set the base uri. By default it's
-        '1'.
+        '1'. If you are using "search.twitter.com" set this to None.
         """
         if not auth:
             auth = NoAuth()
@@ -268,6 +273,12 @@ class Twitter(TwitterCall):
         if (format not in ("json", "xml", "")):
             raise ValueError("Unknown data format '%s'" %(format))
 
+        if api_version is _DEFAULT:
+            if domain == 'api.twitter.com':
+                api_version = '1'
+            else:
+                api_version = None
+
         uriparts = ()
         if api_version:
             uriparts += (str(api_version),)
